%define major	4.14
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d

Name:		gmsh
Version:	4.14.0
Release:	%mkrel 1
Summary:	A three-dimensional finite element mesh generator
License:	GPLv2+
Group:		Sciences/Mathematics
Url:		https://gmsh.info
Source0:	https://gmsh.info/src/%{name}-%{version}-source.tgz
Patch0:		gmsh-4.14.0-fix_install_path.patch
# Unbundle gl2ps
Patch4:		gmsh_unbundle_gl2ps.patch

BuildRequires:	cmake
BuildRequires:	cmake(alglib)
BuildRequires:	cmake(MEDFile)
BuildRequires:	cmake(opencascade)
BuildRequires:	imagemagick
BuildRequires:	gcc-gfortran
BuildRequires:	texinfo
BuildRequires:	cgns-devel
BuildRequires:	getfem-devel
BuildRequires:	gl2ps-devel
BuildRequires:	fltk-devel
BuildRequires:	hdf5-devel
BuildRequires:	libgomp-devel
BuildRequires:	metis-devel
BuildRequires:	pkgconfig(blas)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gmp)
BuildRequires:	pkgconfig(lapack)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)

%description
Gmsh is an automatic 3D finite element grid generator with a
built-in CAD engine and post-processor. Its design goal is to
provide a simple meshing tool for academic problems with
parametric input and advanced visualization capabilities.

Gmsh is built around four modules: geometry, mesh, solver and
post-processing. The specification of any input to these
modules is done either interactively using the graphical user
interface or in ASCII text files using Gmsh's own scripting
language.

%files
%doc README.txt CREDITS.txt CHANGELOG.txt doc/WELCOME.txt
%license LICENSE.txt
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*
%{python3_sitearch}/onelab.py
%{python3_sitearch}/__pycache__/onelab.*
%exclude %{_docdir}/%{name}/*txt
%exclude %{_docdir}/%{name}/examples
%exclude %{_docdir}/%{name}/images
%exclude %{_docdir}/%{name}/tutorials

#----------------------------------------------------------------------------

%package -n	%{libname}
Summary:	A three-dimensional finite element mesh generator
Group:		System/Libraries

%description -n	%{libname}
Gmsh is a 3D finite element grid generator with a build-in CAD engine
and post-processor.

This package contains the shared libraries.

%files -n %{libname}
%doc README.txt
%license LICENSE.txt
%{_libdir}/lib%{name}.so.%{major}{,.*}

#----------------------------------------------------------------------------

%package -n	%{devname}
Summary:	Development files for Gmsh
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
This package contains development files for Gmsh.

%files -n %{devname}
%doc README.txt
%{_includedir}/gmsh.h
%{_includedir}/gmshc.h
%{_includedir}/gmsh.h_cwrap
%{_includedir}/gmsh.f90
%{_libdir}/libgmsh.so

#----------------------------------------------------------------------------

%package -n	python3-%{name}
Summary:	Python3 API for %{name}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n	python3-%{name}
Python3 API for %{name}.

%files -n python3-%{name}
%doc README.txt
%license LICENSE.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/%{name}*.*-info/
%{python3_sitearch}/__pycache__/%{name}.*

#----------------------------------------------------------------------------

%package	demos
Summary:	Tutorial and demo files for Gmsh
Group:		Sciences/Mathematics
BuildArch:	noarch

%description	demos
Gmsh is an automatic 3D finite element grid generator with a
built-in CAD engine and post-processor. Its design goal is to
provide a simple meshing tool for academic problems with
parametric input and advanced visualization capabilities.

Gmsh is built around four modules: geometry, mesh, solver and
post-processing. The specification of any input to these
modules is done either interactively using the graphical user
interface or in ASCII text files using Gmsh's own scripting
language.

This package contains tutorial and demo files for Gmsh.

%files demos
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/tutorials
%{_docdir}/%{name}/examples
%{_docdir}/%{name}/*.txt
%{_docdir}/%{name}/images/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}-source

rm -fr contrib/blossom
rm -fr contrib/mpeg_encode

%build
# mpeg not in mageia due to patent issues
# blossom is nonfree, see contrib/blossom/README.txt

%cmake \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DENABLE_BUILD_LIB:BOOL=OFF \
	-DENABLE_BUILD_DYNAMIC:BOOL=ON \
	-DENABLE_BUILD_SHARED:BOOL=ON \
	-DENABLE_MPEG_ENCODE:BOOL=OFF \
	-DENABLE_BLOSSOM:BOOL=OFF \
	-DENABLE_CGNS:BOOL=ON \
	-DENABLE_ALGLIB:BOOL=ON \
	-DALGLIB_INC=%{_includedir}/alglib \
	-DENABLE_EIGEN:BOOL=ON \
	-DEIGEN_INC=%{_includedir}/eigen3 \
	-DENABLE_MED:BOOL=ON \
	-DENABLE_METIS:BOOL=ON \
	-DENABLE_OCC:BOOL=ON \
	-DENABLE_SYSTEM_CONTRIB:BOOL=ON \
	-DGMSH_HOST=%{_vendor} \
	-DGMSH_PACKAGER='daviddavid'
%cmake_build

%install
%cmake_install

# .deskop
install -dm 0755 %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Version=1.0
Name=Gmsh
GenericName=Mesh Generator
Comment=A 3D finite element mesh generator
Exec=gmsh
Icon=gmsh
Type=Application
Terminal=false
Categories=Science;Engineering;
EOF

# icon
for d in 16 32 48 64 72 128 256 512
do
	install -dm 0755 %{buildroot}%{_iconsdir}/hicolor/${d}x${d}/apps/
	convert -scale ${d}x${d} utils/icons/%{name}.png \
		%{buildroot}%{_iconsdir}/hicolor/${d}x${d}/apps/%{name}.png
done


%changelog
* Thu Jul 17 2025 daviddavid <daviddavid> 4.14.0-1.mga10
+ Revision: 2256788
- new version: 4.14.0

* Thu May 29 2025 daviddavid <daviddavid> 4.13.2-6.mga10
+ Revision: 2186880
- add some fedora patches to fix build

* Tue Mar 04 2025 wally <wally> 4.13.2-5.mga10
+ Revision: 2160368
- rebuild for python3.13

* Mon Mar 03 2025 papoteur <papoteur> 4.13.2-4.mga10
+ Revision: 2159397
- rebuild for python3.13

* Mon Mar 03 2025 papoteur <papoteur> 4.13.2-3.mga10
+ Revision: 2159373
- rebuild for python3.13

* Sat Feb 22 2025 daviddavid <daviddavid> 4.13.2-2.mga10
+ Revision: 2150714
- fix linking issue

* Thu Jun 06 2024 daviddavid <daviddavid> 4.13.2-1.mga10
+ Revision: 2070289
- new version: 4.13.2

* Sat May 11 2024 daviddavid <daviddavid> 4.13.1-1.mga10
+ Revision: 2063755
- new version: 4.13.1
- rebuild for new opencascade

* Thu May 09 2024 wally <wally> 4.13.0-2.mga10
+ Revision: 2063246
- fix build on 32bit arches
- rebuild for cgns 4.4.0

* Fri Mar 01 2024 daviddavid <daviddavid> 4.13.0-1.mga10
+ Revision: 2046216
- new version: 4.13.0

* Thu Jan 25 2024 daviddavid <daviddavid> 4.12.2-1.mga10
+ Revision: 2034148
- new version: 4.12.2

* Sun Jan 14 2024 daviddavid <daviddavid> 4.12.1-1.mga10
+ Revision: 2031173
- new version: 4.12.1

* Wed Dec 27 2023 daviddavid <daviddavid> 4.12.0-1.mga10
+ Revision: 2022529
- new version: 4.12.0
- remove merged upstream patch

* Wed Dec 20 2023 daviddavid <daviddavid> 4.11.1-4.mga10
+ Revision: 2019983
- rebuild for py3.12

* Sat Sep 23 2023 daviddavid <daviddavid> 4.11.1-3.mga10
+ Revision: 1989457
- rebuild for new alglib 4.00.0

* Sat May 20 2023 daviddavid <daviddavid> 4.11.1-2.mga9
+ Revision: 1957437
- set packager option

* Fri May 19 2023 daviddavid <daviddavid> 4.11.1-1.mga9
+ Revision: 1957343
- new version: 4.11.1
+ adrienguichard <adrienguichard>
- Add missing BuildRequires
- do not use wilcard into %%files section
- Add OpenCascade dependency
- imported package gmsh (mga#4113)

